/* List of defines generated by configure. Included with preprocessor flag,
 * -include, to avoid long list of -D defines on the compile command-line.
 * Do not edit.
 */

#ifndef _MOZILLA_CONFIG_H_
#define _MOZILLA_CONFIG_H_

#define ACCESSIBILITY 1
#define D_INO d_ino
#define FUNCPROTO 15
#define HAVE_DIRENT_H 1
#define HAVE_FCHMOD 1
#define HAVE_FLOCKFILE 1
#define HAVE_GETOPT_H 1
#define HAVE_GNU_GET_LIBC_VERSION 1
#define HAVE_GNU_LIBC_VERSION_H 1
#define HAVE_GSSAPI_GSSAPI_GENERIC_H 1
#define HAVE_GSSAPI_GSSAPI_H 1
#define HAVE_I18N_LC_MESSAGES 1
#define HAVE_INT16_T 1
#define HAVE_INT32_T 1
#define HAVE_INT64_T 1
#define HAVE_LCHOWN 1
#define HAVE_LIBDL 1
#define HAVE_LIBM 1
#define HAVE_LOCALTIME_R 1
#define HAVE_MALLOC_H 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMORY_H 1
#define HAVE_MMINTRIN_H 1
#define HAVE_NL_LANGINFO 1
#define HAVE_NL_TYPES_H 1
#define HAVE_RANDOM 1
#define HAVE_RES_NINIT 1
#define HAVE_RINT 1
#define HAVE_SIGINFO_T 1
#define HAVE_SNPRINTF 1
#define HAVE_STRERROR 1
#define HAVE_STRTOK_R 1
#define HAVE_ST_BLKSIZE 1
#define HAVE_SYS_BITYPES_H 1
#define HAVE_SYS_CDEFS_H 1
#define HAVE_SYS_STATFS_H 1
#define HAVE_SYS_STATVFS_H 1
#define HAVE_UINT 1
#define HAVE_UNAME_DOMAINNAME_FIELD 1
#define HAVE_UNISTD_H 1
#define HAVE_VA_COPY 1
#define HAVE_X11_XKBLIB_H 1
#define HAVE_XSHM 1
#define HAVE___CXA_DEMANGLE 1
#define IBMBIDI 1
#define JS_THREADSAFE 1
#define MOZILLA_LOCALE_VERSION "1.7"
#define MOZILLA_REGION_VERSION "1.7"
#define MOZILLA_SKIN_VERSION "1.5"
#define MOZILLA_VERSION "1.7"
#define MOZ_APP_NAME "mozilla"
#define MOZ_BYPASS_PROFILE_AT_STARTUP 1
#define MOZ_DEFAULT_TOOLKIT "gtk"
#define MOZ_DLL_SUFFIX ".so"
#define MOZ_ENABLE_COREXFONTS 1
#define MOZ_ENABLE_OLD_ABI_COMPAT_WRAPPERS 1
#define MOZ_ENABLE_XREMOTE 1
#define MOZ_EXTRA_X11CONVERTERS 1
#define MOZ_JSLOADER 1
#define MOZ_LOGGING 1
#define MOZ_MATHML 1
#define MOZ_PROFILELOCKING 1
#define MOZ_PROFILESHARING 1
#define MOZ_USER_DIR ".mozilla"
#define MOZ_VIEW_SOURCE 1
#define MOZ_WIDGET_GTK 1
#define MOZ_X11 1
#define MOZ_XPINSTALL 1
#define MOZ_XUL 1
#define NS_PRINTING 1
#define NS_PRINT_PREVIEW 1
#define OJI 1
#define STDC_HEADERS 1
#define UNIX_ASYNC_DNS 1
#define VA_COPY va_copy
#define XP_UNIX 1
#define _REENTRANT 1

#endif /* _MOZILLA_CONFIG_H_ */

